@@ -6,7 +6,7 @@ from .appeaser import Appeaser
 from .averagecopier import AverageCopier, NiceAverageCopier
 from .axelrod_first import (
     Davis, RevisedDowning, Feld, Grofman, Nydegger, Joss, Shubik, Tullock,
-    UnnamedStrategy)
+    UnnamedStrategy, SteinAndRapoport)
 from .axelrod_second import Champion, Eatherley, Tester
 from .backstabber import BackStabber, DoubleCrosser
 from .better_and_better import BetterAndBetter
@@ -16,6 +16,7 @@ from .cycler import (
     AntiCycler, Cycler, CyclerCCD, CyclerCCCD, CyclerCCCCCD,
     CyclerDC, CyclerDDC, CyclerCCCDCD)
 from .darwin import Darwin
+from .dbs import DBS
 from .defector import Defector, TrickyDefector
 from .doubler import Doubler
 from .finite_state_machines import (
@@ -75,7 +76,7 @@ from .titfortat import (
     TitForTat, TitFor2Tats, TwoTitsForTat, Bully, SneakyTitForTat,
     SuspiciousTitForTat, AntiTitForTat, HardTitForTat, HardTitFor2Tats,
     OmegaTFT, Gradual, ContriteTitForTat, SlowTitForTwoTats, AdaptiveTitForTat,
-    SpitefulTitForTat, SlowTitForTwoTats2)
+    SpitefulTitForTat, SlowTitForTwoTats2, Alexei)
 from .verybad import VeryBad
 from .worse_and_worse import (WorseAndWorse, KnowledgeableWorseAndWorse,
                               WorseAndWorse2, WorseAndWorse3)
@@ -86,6 +87,7 @@ all_strategies = [
     Adaptive,
     AdaptiveTitForTat,
     Aggravater,
+    Alexei,
     ALLCorALLD,
     Alternator,
     AlternatorHunter,
@@ -115,11 +117,13 @@ all_strategies = [
     CyclerCCCDCD,
     Darwin,
     Davis,
+    DBS,
     Defector,
     DefectorHunter,
     Desperate,
     DoubleCrosser,
     Doubler,
+    DoubleResurrection,
     EasyGo,
     Eatherley,
     EventualCycleHunter,
@@ -228,6 +232,7 @@ all_strategies = [
     SolutionB5,
     SpitefulTitForTat,
     Stalker,
+    SteinAndRapoport,
     StochasticCooperator,
     StochasticWSLS,
     SuspiciousTitForTat,
