@@ -1,6 +1,6 @@
 from axelrod.actions import Actions, Action
 from axelrod.player import Player
-from axelrod.strategy_transformers import TrackHistoryTransformer
+from axelrod.strategy_transformers import TrackHistoryTransformer, FinalTransformer
 
 C, D = Actions.C, Actions.D
 
@@ -425,7 +425,11 @@ class ContriteTitForTat(Player):
         'manipulates_source': False,
         'manipulates_state': False
     }
-    contrite = False
+
+    def __init__(self):
+        super().__init__()
+        self.contrite = False
+        self._recorded_history = []
 
     def strategy(self, opponent: Player) -> Action:
 
@@ -561,7 +565,7 @@ class SpitefulTitForTat(Player):
 
     Names:
 
-    - Spiteful Tit For Tat [PRISON1998]_
+    - Spiteful Tit For Tat [Prison1998]_
     """
 
     name = 'Spiteful Tit For Tat'
@@ -599,6 +603,7 @@ class SpitefulTitForTat(Player):
         super().reset()
         self.retaliating = False
 
+
 class SlowTitForTwoTats2(Player):
     """
     A player plays C twice, then if the opponent plays the same move twice,
@@ -606,7 +611,7 @@ class SlowTitForTwoTats2(Player):
 
     Names:
 
-    - Slow Tit For Tat [PRISON1998]_
+    - Slow Tit For Tat [Prison1998]_
     """
 
     name = 'Slow Tit For Two Tats 2'
@@ -632,3 +637,31 @@ class SlowTitForTwoTats2(Player):
 
         # Otherwise play previous move
         return self.history[-1]
+
+@FinalTransformer((D,), name_prefix=None)
+class Alexei(Player):
+    """
+    Plays similar to Tit-for-Tat, but always defect on last turn.
+    
+    Names:
+
+    - Alexei's Strategy: [LessWrong2011]_    
+    """
+
+    name = 'Alexei'
+    classifier = {
+        'memory_depth': float('inf'),
+        'stochastic': False,
+        'makes_use_of': {'length'},
+        'long_run_time': False,
+        'inspects_source': False,
+        'manipulates_source': False,
+        'manipulates_state': False
+    }
+
+    def strategy(self, opponent: Player) -> Action:
+        if not self.history:
+            return C
+        if opponent.history[-1] == D:
+            return D
+        return C
